Module caex

Module caex 

CITP/CAEX - Capture Extensions layer

The CITP/CAEX “Capture Extensions” layer is a set of networking messages implemented as a private CITP (http://www.citp-protocol.org) layer.

Structs

EnterShow
CAEX / Show Synchronization Messages.
Fixture
FixtureConsoleStatus
This message is sent unsolicited by the peer to Capture in order to convey “live information” data that can be displayed by Capture.
FixtureData
FixtureList
This message is sent in response to a FixtureListRequest message (with Type = 0x00) as well as unsolicited by both Capture and the peer (with Type = 0x01 or Type = 0x02). An existing patch fixture list (Type = 0x00) must contain all known fixtures while a new fixture (Type = 0x01) or exchanged fixture (Type = 0x02) message contains only the fixture(s) that were recently added or exchanged for other fixtures.
FixtureListRequest
This message can be sent unsolicited by Capture or a peer in order to acquire the full patch list from the other side. The expected response is a FixtureList message with Type = 0x00.
FixtureRemove
This message is sent unsolicited by both Capture and the peer whenever on or more fixture(s) have been removed.
FixtureState
GetLaserFeedList
CAEX / Laser Feed Messages.
Header
The CAEX layer provides a standard, single, header used at the start of all CAEX packets.
Identifier
LaserFeedControl
This message is sent by Capture to indicate whether it wishes a laser feed to be transmitted or not. The frame rate can be seen as an indication of the maximum frame rate meaningful to Capture.
LaserFeedFrame
This message is sent unsolicited to Capture, carrying feed frame data.
LaserFeedList
This message can be sent to Capture both in response to a GetLaserFeedList message as well as unsolicited if the list of available laser feeds has changed.
LaserPoint
Example of how a point in constructed
LeaveShow
This message is sent unsolicited by both Capture and the peer when a show/project is closed or when the user wishes to disable show synchronization.
Message
Layout of CAEX messages.
Nack
This message must be sent by Capture or a peer in response to any unknown message or any request that prompts a reply which cannot be served. The CITP header RequestIndex and InResponseTo fields must be honored when sending this message.

Enums

FixtureListMessageType
IdentifierType
NackReason