#[repr(C)]pub struct LeaveShow {}Expand description
This message is sent unsolicited by both Capture and the peer when a show/project is closed or when the user wishes to disable show synchronization.
Implementations